OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "לא ניתן לכתוב לתיקיית „config”!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "בדרך כלל ניתן לפתור את הבעיה על ידי כך שנותנים לתכנית השרת הרשאות כתיבה לתיקיית config",
    "See %s" : "יש לעיין ב־%s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "או, אם עדיף לך לשמור על config.php לקריאה בלבד, ניתן להגדיר את האפשרות „config_is_read_only” לערך true.",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "בדרך כלל ניתן לתקן זאת על ידי הענקת גישה לשרת לכתוב לתיקיית ההגדרות. נא לעיין ב־%s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "או, אם עדיף לך לשמור על config.php לקריאה בלבד, ניתן להגדיר את האפשרות „config_is_read_only” לערך true. נא לעיין ב־%s",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "הקבצים של היישומון %1$s לא מוקמו במקום הנכון. נא לוודא שזו גרסה שהשרת תומך בה.",
    "Sample configuration detected" : "התגלתה דוגמת תצורה",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "התגלה שדוגמת התצורה הועתקה. דבר זה עלול לשבור את ההתקנה ולא נתמך.יש לקרוא את מסמכי התיעוד לפני שמבצעים שינויים ב- config.php",
    "Education Edition" : "מהדורה חינוכית",
    "Enterprise bundle" : "מהדורה מסחרית",
    "Groupware bundle" : "מהדורה קבוצתית",
    "Social sharing bundle" : "מאגד שיתוף חברתי",
    "PHP %s or higher is required." : "נדרש PHP בגרסת %s ומעלה.",
    "PHP with a version lower than %s is required." : "נדרש PHP בגרסה נמוכה מ- %s.",
    "%sbit or higher PHP required." : "נדרש PHP בגרסת %s ומעלה.",
    "Following databases are supported: %s" : "מסדי הנתונים הבאים נתמכים: %s",
    "The command line tool %s could not be found" : "כלי שורת הפקודה %s לא אותר",
    "The library %s is not available." : "הספריה %s אינה זמינה.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "נדרשת ספרייה %1$s עם גרסה מתחת ל־%2$s - הגרסה הזמינה היא %3$s.",
    "Following platforms are supported: %s" : "הפלטפורמות הבאות נתמכות: %s",
    "Server version %s or higher is required." : "נדרשת גרסה שרת %s ומעלה.",
    "Server version %s or lower is required." : "נדרשת גרסה שרת %s ומטה.",
    "Logged in user must be an admin" : "על המשתמש שנכנס להיות מנהל",
    "Authentication" : "אימות",
    "Unknown filetype" : "סוג קובץ לא מוכר",
    "Invalid image" : "תמונה לא חוקית",
    "Avatar image is not square" : "התמונה המייצגת אינה מרובעת",
    "today" : "היום",
    "tomorrow" : "מחר",
    "yesterday" : "אתמול",
    "_in %n day_::_in %n days_" : ["בעוד יום","בעוד יומיים","בעוד %n ימים","בעוד %n ימים"],
    "_%n day ago_::_%n days ago_" : ["לפני %n יום","לפני %n ימים","לפני %n ימים","לפני %n ימים"],
    "next month" : "בחודש הבא",
    "last month" : "חודש שעבר",
    "_in %n month_::_in %n months_" : ["בעוד חודש","בעוד חודשיים","בעוד %n חודשים","בעוד %n חודשים"],
    "_%n month ago_::_%n months ago_" : ["לפני חודש","לפני חודשיים","לפני %n חודשים","לפני %n חודשים"],
    "next year" : "בשנה הבאה",
    "last year" : "שנה שעברה",
    "_in %n year_::_in %n years_" : ["בעוד שנה","בעוד שנתיים","בעוד %n שנים","בעוד %n שנים"],
    "_%n year ago_::_%n years ago_" : ["לפני %n שנה","לפני %n שנים","לפני %n שנים","לפני %n שנים"],
    "_in %n hour_::_in %n hours_" : ["בעוד שעה","בעוד שעתיים","בעוד %n שעות","בעוד %n שעות"],
    "_%n hour ago_::_%n hours ago_" : ["לפני שעה","לפני שעתיים","לפני %n שעות","לפני %n שעות"],
    "_in %n minute_::_in %n minutes_" : ["בעוד דקה","בעוד 2 דקות","בעוד %n דקות","בעוד %n דקות"],
    "_%n minute ago_::_%n minutes ago_" : ["לפני דקה","לפני 2 דקות","לפני %n דקות","לפני %n דקות"],
    "in a few seconds" : "בעוד מספר שניות",
    "seconds ago" : "שניות",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "המודול עם המזהה: %s לא קיים. נא להפעיל אותו בהגדרות היישומונים שלך או ליצור קשר עם מנהל המערכת.",
    "File name is a reserved word" : "שם קובץ הוא מילה שמורה",
    "File name contains at least one invalid character" : "שם הקובץ כולל לפחות תו אחד לא חוקי",
    "File name is too long" : "שם קובץ ארוך מדי",
    "Dot files are not allowed" : "אסור ששמות קבצים יתחילו בנקודה",
    "Empty filename is not allowed" : "שם קובץ ריק אינו מאושר",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "יישום \"%s\" לא ניתן להתקנה כיוון שקובץ appinfo לא ניתן לקריאה.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "לא ניתן להתקין את היישומון „%s” כיוון שאין לו תמיכה בגרסה זו של השרת.",
    "__language_name__" : "עברית",
    "This is an automatically sent email, please do not reply." : "זו הודעת דוא״ל שנשלחה אוטומטית, נא לא להגיב.",
    "Help" : "עזרה",
    "Apps" : "יישומים",
    "Settings" : "הגדרות",
    "Log out" : "התנתק",
    "Users" : "משתמשים",
    "Unknown user" : "משתמש לא ידוע",
    "Overview" : "סקירה",
    "Basic settings" : "הגדרות בסיסיות",
    "Sharing" : "שיתוף",
    "Security" : "אבטחה",
    "Groupware" : "קבוצתי",
    "Additional settings" : "הגדרות נוספות",
    "Personal info" : "פרטים אישיים",
    "Mobile & desktop" : "נייד ושולחן עבודה",
    "%s enter the database username and name." : "%s יש להכניס את שם המשתמש ושם מסד הנתונים.",
    "%s enter the database username." : "%s נכנס למסד נתוני שמות המשתמשים.",
    "%s enter the database name." : "%s נכנס למסד נתוני השמות.",
    "%s you may not use dots in the database name" : "%s לא ניתן להשתמש בנקודות בשם מסד הנתונים",
    "Oracle connection could not be established" : "לא ניתן היה ליצור חיבור Oracle",
    "Oracle username and/or password not valid" : "שם משתמש ו/או סיסמת Oracle אינם תקפים",
    "PostgreSQL username and/or password not valid" : "שם משתמש ו/או סיסמת PostgreSQL אינם תקפים",
    "You need to enter details of an existing account." : "עליך להקליד פרטים של חשבון קיים.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X אינו נתמך ו- %s לא יעבוד כשורה בפלטפורמה זו. ניתן לקחת סיכון ולהשתמש באחריותך! ",
    "For the best results, please consider using a GNU/Linux server instead." : "לתוצאות הכי טובות, יש לשקול שימוש בשרת GNU/Linux במקום.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "נראה ש- %s עובד על בסיס סביבת 32-bit PHP ושה- open_basedir הוגדר בקובץ php.ini. מצב זה יוביל לבעיות עם קבצים הגדולים מ- 4 GB ואינו מומלץ לחלוטין.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "יש להסיר את הגדרת open_basedir מתוך קובץ php.ini או להחליף לסביבת 64-bit PHP.",
    "Set an admin username." : "קביעת שם משתמש מנהל",
    "Set an admin password." : "קביעת סיסמת מנהל",
    "Can't create or write into the data directory %s" : "לא ניתן ליצור או לכתוב לתוך תיקיית הנתונים %s",
    "Invalid Federated Cloud ID" : "זיהוי ענן מאוגד לא חוקי",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "צד אחורי לשיתוף %s חייב ליישם את ממשק OCP\\Share_Backend",
    "Sharing backend %s not found" : "צד אחורי לשיתוף %s לא נמצא",
    "Sharing backend for %s not found" : "צד אחורי לשיתוף של %s לא נמצא",
    "Open »%s«" : "פתיחת „%s”",
    "You are not allowed to share %s" : "אינך רשאי/ת לשתף %s",
    "Can’t increase permissions of %s" : "לא ניתן לחזק את ההרשאות של %s",
    "Files can’t be shared with delete permissions" : "לא ניתן לשתף קבצים עם הרשאת מחיקה",
    "Files can’t be shared with create permissions" : "לא ניתן לשתף קבצים עם הרשאות יצירה",
    "Expiration date is in the past" : "תאריך תפוגה הנו בעבר",
    "Can’t set expiration date more than %s days in the future" : "לא ניתן להגדיר את תאריך התפוגה מעל %s ימים בעתיד",
    "Click the button below to open it." : "יש ללחוץ על הכפתור להלן כדי לפתוח אותו.",
    "The requested share does not exist anymore" : "השיתוף המבוקש אינו קיים עוד",
    "Could not find category \"%s\"" : "לא ניתן למצוא את הקטגוריה „%s“",
    "Sunday" : "יום ראשון",
    "Monday" : "יום שני",
    "Tuesday" : "יום שלישי",
    "Wednesday" : "יום רביעי",
    "Thursday" : "יום חמישי",
    "Friday" : "יום שישי",
    "Saturday" : "שבת",
    "Sun." : "ראשון",
    "Mon." : "שני",
    "Tue." : "שלישי",
    "Wed." : "רביעי",
    "Thu." : "חמישי",
    "Fri." : "שישי",
    "Sat." : "שבת",
    "Su" : "א",
    "Mo" : "ב",
    "Tu" : "ג",
    "We" : "ד",
    "Th" : "ה",
    "Fr" : "ו",
    "Sa" : "ש",
    "January" : "ינואר",
    "February" : "פברואר",
    "March" : "מרץ",
    "April" : "אפריל",
    "May" : "מאי",
    "June" : "יוני",
    "July" : "יולי",
    "August" : "אוגוסט",
    "September" : "ספטמבר",
    "October" : "אוקטובר",
    "November" : "נובמבר",
    "December" : "דצמבר",
    "Jan." : "ינו׳",
    "Feb." : "פבר׳",
    "Mar." : "מרץ",
    "Apr." : "אפר׳",
    "May." : "מאי",
    "Jun." : "יונ׳",
    "Jul." : "יול׳",
    "Aug." : "אוג׳",
    "Sep." : "ספט׳",
    "Oct." : "אוק׳",
    "Nov." : "נוב׳",
    "Dec." : "דצמ׳",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "רק התווים הבאים מאושרים לשם משתמש: \"a-z\", \"A-Z\", \"0-9\", וגם \"_.@-'\"",
    "A valid username must be provided" : "יש לספק שם משתמש תקני",
    "Username contains whitespace at the beginning or at the end" : "שם המשתמש מכיל רווח בתחילתו או בסופו",
    "Username must not consist of dots only" : "שם המשתמש לא יכול להיות מורכב מנקודות בלבד",
    "A valid password must be provided" : "יש לספק ססמה תקנית",
    "The username is already being used" : "השם משתמש כבר בשימוש",
    "Could not create user" : "לא ניתן ליצור משתמש",
    "User disabled" : "משתמש מנוטרל",
    "Login canceled by app" : "התחברות בוטלה על ידי יישום",
    "a safe home for all your data" : "בית בטוח עבור כל המידע שלך",
    "File is currently busy, please try again later" : "הקובץ בשימוש כרגע, יש לנסות שוב מאוחר יותר",
    "Can't read file" : "לא ניתן לקרוא קובץ",
    "Application is not enabled" : "יישומים אינם מופעלים",
    "Authentication error" : "שגיאת הזדהות",
    "Token expired. Please reload page." : "פג תוקף. נא לטעון שוב את הדף.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "לא מותקנים דרייברים למסד הנתונים (sqlite, mysql, או postgresql).",
    "Cannot write into \"config\" directory" : "לא ניתן לכתוב לתיקיית \"config\"!",
    "Cannot write into \"apps\" directory" : "לא ניתן לכתוב לתיקיית \"apps\"",
    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "בדרך כלל ניתן לתקן זאת על ידי הענקת גישה לשרת לכתוב לתיקיית היישומונים או להשבית את חנות היישומונים בקובץ ההגדרות. נא לעיין ב־%s",
    "Cannot create \"data\" directory" : "לא ניתן ליצור תיקיית „data”",
    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "בדרך כלל ניתן לתקן זאת על ידי הענקת גישה לשרת לכתוב לתיקיית הבסיס. נא לעיין ב־%s",
    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "בדרך כלל ניתן לתקן הרשאות על ידי מתן גישה לשרת שלך אל תיקיית העל. נא לעיין ב־%s.",
    "Setting locale to %s failed" : "הגדרת שפה ל- %s נכשלה",
    "Please install one of these locales on your system and restart your webserver." : "יש להתקין אחת מהשפות על המערכת שלך ולהפעיל מחדש את שרת האינטרנט.",
    "Please ask your server administrator to install the module." : "יש לבקש ממנהל השרת שלך להתקין את המודול.",
    "PHP module %s not installed." : "מודול PHP %s אינו מותקן.",
    "PHP setting \"%s\" is not set to \"%s\"." : "הגדרות PHP \"%s\" אינם מוגדרות ל- \"%s\"",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "התאמת ההגדרה הזו ב־php.ini יאפשר ל־Nextcloud לפעול שוב",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload מוגדר ל- \"%s\" במקום הערך המצופה \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "לתיקון בעיה זו יש להגדיר <code>mbstring.func_overload</code> כ- <code>0</code> iבקובץ ה- php.ini שלך",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 נדרש לכל הפחות. כרגע %s מותקן.",
    "To fix this issue update your libxml2 version and restart your web server." : "לתיקון הבעיה יש לעדכן את גרסת ה- libxml2 שלך ולהפעיל מחדש את שרת האינטרנט שלך.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ככל הנראה מוגדר ל- strip inline doc blocks. זה יגרום למספר יישומי ליבה לא להיות נגישים.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "זה ככל הנראה נגרם על ידי מאיץ/מטמון כמו Zend OPcache או eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "מודולי PHP הותקנו, אך עדיין רשומים כחסרים?",
    "Please ask your server administrator to restart the web server." : "יש לבקש ממנהל השרת שלך להפעיל מחדש את שרת האינטרנט.",
    "PostgreSQL >= 9 required" : "נדרש PostgreSQL >= 9",
    "Please upgrade your database version" : "יש לשדרג את גרסת מסד הנתונים שלך",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "יש לשנות את ההרשאות ל- 0770 כך שהתיקייה לא תרשם על ידי משתמשים אחרים.",
    "Your data directory is readable by other users" : "תיקיית הנתונים שלך ניתנת לקריאה על ידי משתמשים אחרים",
    "Your data directory must be an absolute path" : "תיקיית הנתונים שלך חייבת להיות במבנה של נתיב מלא (מיקום מוחלט)",
    "Check the value of \"datadirectory\" in your configuration" : "יש לבדוק את הערך \"datadirectory\" בהגדרות התצורה שלך",
    "Your data directory is invalid" : "תיקיית הנתונים שלך שגויה",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "נא לוודא שיש קובץ בשם „‎.ocdata” בבסיס תיקיית הנתונים שלך.",
    "Action \"%s\" not supported or implemented." : "הפעולה „%s” אינה נתמכת או שאינה מוטמעת.",
    "Authentication failed, wrong token or provider ID given" : "האימות נכשל, האסימון או מזהה הספק שסופקו שגויים",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "חסרים משתנים להשלמת הבקשה. המשתנים החסרים: „%s”",
    "Could not obtain lock type %d on \"%s\"." : "לא ניתן היה להשיג סוג נעילה %d ב- \"%s\".",
    "Storage unauthorized. %s" : "אחסון לא מורשה. %s",
    "Storage incomplete configuration. %s" : "תצורה לא מושלמת של האחסון. %s",
    "Storage connection error. %s" : "שגיאת חיבור אחסון. %s",
    "Storage is temporarily not available" : "האחסון אינו זמין כרגע",
    "Storage connection timeout. %s" : "פסק זמן חיבור אחסון. %s",
    "Create" : "יצירה",
    "Change" : "שינוי",
    "Delete" : "מחיקה",
    "Share" : "שיתוף",
    "Unlimited" : "ללא הגבלה",
    "Verifying" : "מתבצע אימות",
    "Verifying …" : "מתבצע אימות…",
    "Verify" : "אימות",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "השיתוף %s נכשל, כיוון שהצד האחורי אינו מאפשר שיתופים מסוג %i",
    "Sharing %s failed, because the file does not exist" : "השיתוף %s נכשל, כיוון שהקובץ אינו קיים",
    "Sharing %s failed, because you can not share with yourself" : "השיתוף %s נכשל, כיוון שלא ניתן לשתף עם עצמך",
    "Sharing %1$s failed, because the user %2$s does not exist" : "השיתוף של %1$s נכשל כיוון שהמשתמש %2$s אינו קיים",
    "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "השיתוף של %1$s נכשל, כיוון שהמשתמש %2$s אינו חבר בקבוצות באף קבוצה בה יש ל־%3$s חברות בה",
    "You need to provide a password to create a public link, only protected links are allowed" : "יש לספק סיסמא ליצירת קישור ציבורי, רק קישורים מוגנים מותרים",
    "Sharing %s failed, because sharing with links is not allowed" : "השיתוף %s נכשל, כיוון ששיתוף עם קישור אינו מותר",
    "Not allowed to create a federated share with the same user" : "אסור ליצור שיתוף מאוגד עם אותו משתמש",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "לא ניתן לקבוע תאריך תפוגה. שיתופים אינם יכולים לפוג תוקף מאוחר יותר מ- %s לאחר ששותפו",
    "Cannot set expiration date. Expiration date is in the past" : "לא ניתן לקבוע תאריך תפוגה. תאריך התפוגה הנו בעבר",
    "Sharing failed, because the user %s is the original sharer" : "שיתוף נכשל, כיוון שמשתמש %s הנו המשתף המקורי",
    "Sharing %s failed, because resharing is not allowed" : "השיתוף %s נכשל, כיוון ששיתוף מחודש אסור",
    "Sharing %s failed, because the file could not be found in the file cache" : "השיתוף %s נכשל, כייון שלא ניתן היה למצוא את הקובץ בזכרון המטמון"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
